==> imageio-ext-gdalmrsidjp2-1.4-20250808.154548-47-sources.jar: it/geosolutions/imageio/plugins/jp2mrsid/JP2GDALMrSidImageReader.java <==
/*
 *    ImageI/O-Ext - OpenSource Java Image translation Library
 *    http://www.geo-solutions.it/
 *    https://github.com/geosolutions-it/imageio-ext
 *    (C) 2007 - 2009, GeoSolutions
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    either version 3 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package it.geosolutions.imageio.plugins.jp2mrsid;

import it.geosolutions.imageio.gdalframework.GDALImageReader;

import java.awt.image.RenderedImage;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * {@link JP2GDALMrSidImageReader} is a {@link GDALImageReader} able to create
 * {@link RenderedImage} from JP2K files.
 * 
 * @author Daniele Romagnoli, GeoSolutions.
 * @author Simone Giannecchini, GeoSolutions.
 */
public class JP2GDALMrSidImageReader extends GDALImageReader {

    private static final Logger LOGGER = Logger
            .getLogger("it.geosolutions.imageio.plugins.jp2mrsid");

    /**
     * Constructs a <code>JP2GDALMrSidImageReader<code> using a 
     * {@link JP2GDALMrSidImageReaderSpi}.
     * 
     * @param originatingProvider
     *            The {@link JP2GDALMrSidImageReaderSpi} to use for building 
     *            this <code>JP2GDALMrSidImageReader<code>.
     */
    public JP2GDALMrSidImageReader(
            JP2GDALMrSidImageReaderSpi originatingProvider) {
        super(originatingProvider, 0);
        if (LOGGER.isLoggable(Level.FINE))
            LOGGER.fine("JP2GDALMrSidImageReader Constructor");
    }

}

==> imageio-ext-gdalmrsidjp2-2.0.1-sources.jar: it/geosolutions/imageio/plugins/jp2mrsid/JP2GDALMrSidImageReader.java <==
/*
 *    ImageI/O-Ext - OpenSource Java Image translation Library
 *    http://www.geo-solutions.it/
 *    https://github.com/geosolutions-it/imageio-ext
 *    (C) 2007 - 2009, GeoSolutions
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    either version 3 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package it.geosolutions.imageio.plugins.jp2mrsid;

import it.geosolutions.imageio.gdalframework.GDALImageReader;
import java.awt.image.RenderedImage;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * {@link JP2GDALMrSidImageReader} is a {@link GDALImageReader} able to create {@link RenderedImage} from JP2K files.
 *
 * @author Daniele Romagnoli, GeoSolutions.
 * @author Simone Giannecchini, GeoSolutions.
 */
public class JP2GDALMrSidImageReader extends GDALImageReader {

    private static final Logger LOGGER = Logger.getLogger("it.geosolutions.imageio.plugins.jp2mrsid");

    /**
     * Constructs a <code>JP2GDALMrSidImageReader<code> using a
     * {@link JP2GDALMrSidImageReaderSpi}.
     *
     * @param originatingProvider
     *            The {@link JP2GDALMrSidImageReaderSpi} to use for building
     *            this <code>JP2GDALMrSidImageReader<code>.
     */
    public JP2GDALMrSidImageReader(JP2GDALMrSidImageReaderSpi originatingProvider) {
        super(originatingProvider, 0);
        if (LOGGER.isLoggable(Level.FINE)) LOGGER.fine("JP2GDALMrSidImageReader Constructor");
    }
}
